﻿using Hotline.Share.Requests;
using System.ComponentModel.DataAnnotations;

namespace Hotline.Share.Dtos.CallCenter;

public record BiQueryCallsDto : ReportPagedRequest
{
    /// <summary>
    /// 开始时间
    /// </summary>
    [Required(ErrorMessage = "开始时间不能为空")]
    public override DateTime? StartTime
    {
        get { return base.StartTime ?? throw new InvalidOperationException("开始时间不能为空"); }
        set { base.StartTime = value; }
    }

    /// <summary>
    /// 结束时间
    /// </summary>
    [Required(ErrorMessage = "结束时间不能为空")]
    public override DateTime? EndTime
    {
        get {
            if (base.EndTime == null)
                throw new InvalidOperationException("结束时间不能为空");
            if (base.EndTime.Value.Hour == 0 && base.EndTime.Value.Minute == 0 && base.EndTime.Value.Second == 0)
                return base.EndTime.Value.AddDays(1).AddSeconds(-1);
            return base.EndTime; 
        }
        set { base.EndTime = value; }
    }

    /// <summary>
    /// 线路
    /// </summary>
    public string? Line { get; set; }

    /// <summary>
    /// 查询类型 1：呼入总量明细；2：接通总量明细
    /// </summary>
    public string? TypeCode { get; set; } = "1";
}

public record QueryCallListDto : PagedRequest
{
    [Required(ErrorMessage = "开始时间不能为空")]
    public DateTime StartTime { get; set; }
    [Required(ErrorMessage = "结束时间不能为空")]
    public DateTime EndTime { get; set; }
    public string Type { get; set; }
    public string Source { get; set; }
    public TimeSpan? StartHourTo { get; set; }
}

public class BiQueryHourCallDto
{

    public DateTime StartTime { get; set; }

    [Required(ErrorMessage = "结束时间不能为空")]
    public DateTime EndTime { get; set; }
    public string Source { get; set; }
}

public class BiQueryGateWayDto
{
    public DateTime StartTime { get; set; }

    public DateTime EndTime { get; set; }

    public string Gateway { get; set; }
}

public class TotalList<T>
{
    public TotalList()
    {

    }
    public TotalList(List<T> list, T total)
    {
        List = list;
        Total = total;
    }

    public T Total { get; set; }
    public List<T> List { get; set; }
}

public class TotalData<T>
{
    public TotalData()
    {

    }
    public TotalData(List<T> list, int total)
    {
        Data = list;
        Total = total;
    }

    public int Total { get; set; }
    public List<T> Data { get; set; }
}